"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _Content_instances, _Content_modifySmiles;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Content = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const BaseContent_1 = require("./BaseContent");
const SimpleUser_1 = require("./SimpleUser");
/**
 * Represents content from iFunny
 * @extends BaseContent
 */
class Content extends BaseContent_1.BaseContent {
    /**
     * @param client Client attached to the Content
     * @param payload Payload of the content
     */
    constructor(client, payload) {
        super(client, payload);
        _Content_instances.add(this);
    }
    /**
     * Cycles through users that smiled the post
     * @param limit How many users to return per request (Default: `30`)
     */
    async *smiles(limit = 30) {
        for await (const data of this.client.util.paginate(ifunny_api_types_1.Endpoints.smiles(this.id), "users", { limit }, true)) {
            for (const user of data.data.users.items) {
                this.payload.num.smiles = data.data.smiles_count;
                this.payload.num.guest_smiles = data.data.guest_smiles_count;
                yield new SimpleUser_1.SimpleUser(this.client, user);
            }
        }
    }
    /**
     * Smiles the post
     * @param from Where the action occured
     * @returns Was it success
     */
    async smile(from) {
        return await __classPrivateFieldGet(this, _Content_instances, "m", _Content_modifySmiles).call(this, "PUT", "smiles", { from });
    }
    /**
     * Removes the Client's smile
     * @param from Where the action occured
     * @returns Was it success
     */
    async removeSmile(from) {
        return await __classPrivateFieldGet(this, _Content_instances, "m", _Content_modifySmiles).call(this, "DELETE", "smiles", { from });
    }
    /**
     * Unsmiles the post
     * @param from Where the action occured
     * @returns Was it success
     */
    async unsmile(from) {
        return await __classPrivateFieldGet(this, _Content_instances, "m", _Content_modifySmiles).call(this, "PUT", "unsmiles", { from });
    }
    /**
     * Removes the Client's unsmile
     * @param from Where the content was smiled
     * @returns Was the content marked as smiled
     */
    async removeUnsmile(from) {
        return await __classPrivateFieldGet(this, _Content_instances, "m", _Content_modifySmiles).call(this, "DELETE", "unsmiles", { from });
    }
}
exports.Content = Content;
_Content_instances = new WeakSet(), _Content_modifySmiles = 
/**
 * Helper method to modify smiles for the content
 * @param method HTTP method
 * @param type `smiles` or `unsmiles`
 * @param params Params to pass to the request
 * @internal
 */
async function _Content_modifySmiles(method, type, params) {
    const response = await this.client.instance.request({
        method,
        url: ifunny_api_types_1.Endpoints[type](this.id),
        params,
    });
    // Update payload
    this.payload.num.smiles = response.data.data.num_smiles;
    this.payload.num.unsmiles = response.data.data.num_unsmiles;
    this.payload.num.guest_smiles = response.data.data.num_guest_smiles;
    return response.data.status == 200;
};
exports.default = Content;
//# sourceMappingURL=Content.js.map