"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Feed = void 0;
const BaseFeed_1 = require("./BaseFeed");
const Content_1 = require("./Content");
/**
 * Represents a feed on iFunny
 * @extends BaseFeed
 */
class Feed extends BaseFeed_1.BaseFeed {
    /**
     * @param client Client attached to the Feed
     * @param url Url for the feed
     */
    constructor(client, url) {
        super(client, url);
    }
    /**
     * Scrolls through content in a feed from left to right
     * @param params Params to pass into the pagination requests - Updates automatically
     * @param markAsRead Should each post be marked as read after viewing? (Default: false)
     */
    async *scroll(params, markAsRead = false) {
        for await (const api_content of this.client.util.paginate(this.url, "content", Object.assign({ limit: 30 }, params))) {
            if (markAsRead) {
                this.client.content.markAsRead(api_content.id);
            }
            const content = new Content_1.Content(this.client, api_content);
            this.client.content.cache.set(content.id, content);
            yield content;
        }
    }
}
exports.Feed = Feed;
exports.default = Feed;
//# sourceMappingURL=Feed.js.map