"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var _SimpleUser_user;
Object.defineProperty(exports, "__esModule", { value: true });
exports.SimpleUser = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const Base_1 = require("./Base");
/**
 * Simple user class, typically found in pagination
 * @extends Base<APISimpleUser>
 */
class SimpleUser extends Base_1.Base {
    /**
     * @param client Client attached to the SimpleUser
     * @param payload Payload for the SimpleUser
     */
    constructor(client, payload) {
        super(client, payload);
        /**
         * Cached user to prevent multiple API calls
         */
        _SimpleUser_user.set(this, null);
        this.endpointUrl = ifunny_api_types_1.Endpoints.user(this.id);
    }
    /**
     * Fetches the User object
     * @returns The User object with more information
     */
    async user() {
        return (__classPrivateFieldSet(this, _SimpleUser_user, __classPrivateFieldGet(this, _SimpleUser_user, "f") ?? await this.client.users.fetch(this.id), "f"));
    }
    /**
     * Is the user banned?
     */
    get isBanned() {
        return this.get("is_banned");
    }
    /**
     * Is the user blocked by the Client?
     */
    get isBlocked() {
        return this.get("is_blocked");
    }
    /**
     * Is the user deleted?
     */
    get isDeleted() {
        return this.get("is_deleted");
    }
    /**
     * Is the user subcribed to the Client?
     */
    get isSubscriber() {
        return this.get("is_in_subscribers");
    }
    /**
     * Is the Cilent subscribed to the user?
     */
    get isSubscription() {
        return this.get("is_in_subscriptions");
    }
    /**
     * Is the user verified?
     */
    get isVerified() {
        return this.get("is_verified");
    }
    /**
     * User's nick
     * @alias username
     */
    get nick() {
        return this.get("nick");
    }
    /**
     * Nums for the user
     * @alias stats
     */
    get num() {
        return this.get("num");
    }
    /**
     * Original nick for the user
     */
    get originalNick() {
        return this.get("original_nick");
    }
    /**
     * Profile photo for the user
     */
    get photo() {
        return this.get("photo");
    }
    /**
     * Stats for the user
     * @alias num
     */
    get stats() {
        return this.num;
    }
    /**
     * Amount of posts the user has
     */
    get totalPosts() {
        return this.get("total_posts");
    }
    /**
     * Amount of subscribers the user has
     */
    get totalSubscribers() {
        return this.num.subscribers;
    }
    /**
     * Amount of subcriptions the user has
     */
    get totalSubscriptions() {
        return this.num.subscriptions;
    }
    /**
     * User's nick
     * @alias nick
     */
    get username() {
        return this.nick;
    }
    /**
     * When concatenated with a string, this automatically returns the user's nick instead of the User object.
     * @example
     * console.log(`Hello from ${user}!`); //  Logs: Hello from iFunnyChef
     */
    toString() {
        return this.nick;
    }
}
exports.SimpleUser = SimpleUser;
_SimpleUser_user = new WeakMap();
exports.default = SimpleUser;
//# sourceMappingURL=SimpleUser.js.map