import { type APIBan, type APIBanReason, type APIBanType } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import { Comment } from "./Comment";
import { Content } from "./Content";
import type { User } from "./User";
/**
 * Represents a complete Ban Object on iFunny
 * @extends Base<APIBan>
 */
export declare class Ban extends Base<APIBan> {
    #private;
    /**
     * @param user User the ban is attached to
     * @param payload The payload of the Ban
     */
    constructor(user: User, payload: APIBan);
    /**
     * The user attached to the Ban
     */
    get user(): User;
    /**
     * The type of ban
     */
    get type(): APIBanType;
    /**
     * Timestamp of when the Ban expires
     */
    get expiresAt(): Date;
    /**
     * How long (in miliseconds) until the Ban expires
     */
    get expiresIn(): number;
    /**
     * The reason for the Ban
     */
    get reason(): APIBanReason;
    /**
     * The ban reason message
     */
    get reasonMessage(): string | null;
    /**
     * Can the ban be appealed?
     */
    get canBeAppealed(): boolean;
    /**
     * When the ban was created
     */
    get createdAt(): Date;
    /**
     * Not sure what this is
     */
    get dateUntilMinimum(): number | null;
    /**
     * Is the Ban active?
     */
    get isActive(): boolean;
    /**
     * Has the Ban be appealed?
     */
    get isAppealed(): boolean;
    /**
     * Is the ban shortable?
     */
    get isShortable(): boolean;
    /**
     * Don't know what this is yet
     */
    get pid(): number;
    /**
     * The Comment related to the Ban if applicable
     */
    get relatedComment(): Comment | null;
    /**
     * The Content related to the Ban if applicable
     */
    get relatedContent(): Content | null;
    /**
     * The Ban Type message
     */
    get typeMessage(): string | null;
    /**
     * Was the Ban shown to the Client?
     */
    get wasShown(): boolean;
}
export default Ban;
//# sourceMappingURL=Ban.d.ts.map