import { type APIComment, type APICommentNum, type APICommentState } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import { Comment } from "./Comment";
import { SimpleUser } from "./SimpleUser";
import { Thumbnail } from "./Thumbnail";
import type { Content } from "./Content";
/**
 * Represents a BaseComment on iFunny
 * @extends Base<APIComment>
 */
export declare class BaseComment extends Base<APIComment> {
    #private;
    /**
     * @param content Content the Comment is attached to
     * @param payload Payload of the Comment
     */
    constructor(content: Content, payload: APIComment);
    /**
     * Content ID the comment is attached to
     */
    get contentId(): string;
    /**
     * Content attached to the Comment
     */
    get content(): Content;
    /**
     * Thumbnails for the content
     */
    get thumbnails(): Thumbnail | null;
    /**
     * Returns the date when the comment was created.
     * @returns The comment's date as a `Date` object.
     */
    get date(): Date;
    /**
     * Whether the comment has been edited.
     * @returns True if the comment has been edited, false otherwise.
     */
    get isEdited(): boolean;
    /**
     * Whether the comment is a reply to another comment.
     * @returns True if the comment is a reply, false otherwise.
     */
    get isReply(): boolean;
    /**
     * Whether the comment has been smiled by the user.
     * @returns True if the comment has been smiled, false otherwise.
     */
    get isSmiled(): boolean;
    /**
     * Whether the user has un-smiled the comment.
     * @returns True if the comment has been un-smiled, false otherwise.
     */
    get isUnsmiled(): boolean;
    /**
     * The last reply to the comment.
     * @returns The last reply to the comment, or null if there are no replies.
     */
    get lastReply(): Comment | null;
    /**
     * The number of the comment.
     * @returns The number of the comment.
     */
    get num(): APICommentNum;
    /**
     * The state of the comment.
     * @returns The state of the comment, or null if the state is not available.
     */
    get state(): APICommentState | null;
    /**
     * The text of the Comment. Can be an empty string
     */
    get text(): string;
    /**
     * Author of the Comment
     * @alias creator
     * @example
     * const author = comment.author; // SimpleUser
     * const user = await author.user(); // Full User
     */
    get author(): SimpleUser | null;
    /**
     * Author of the Comment
     * @alias author
     * @example
     * const author = comment.author; // SimpleUser
     * const user = await author.user(); // Full User
     */
    get creator(): SimpleUser | null;
}
export default BaseComment;
//# sourceMappingURL=BaseComment.d.ts.map