import { AxiosRequestHeaders } from "axios";
import type { BasicAuthConfig } from "./Types";
import type { Client } from "../client/Client";
/**
 * Utility class used by the Client
 */
export declare class Util {
    #private;
    /**
     * @param client Client attached to the Utility class
     */
    constructor(client: Client);
    /**
     * Generates a basic token
     * @param opts Options to create the token with
     * @param opts.clientId The client id to use for the token
     * @param opts.clientSecret The client secret to use for the token
     * @param opts.length The length of the token to create
     * @returns A basic auth token
     */
    createBasicAuth(opts?: BasicAuthConfig): string;
    /**
     * Sleeps the program for the specified amount of milliseconds
     * @param ms The number of milliseconds to wait
     * @returns A promise that resolves after the given amount of time
     */
    sleep(ms: number): Promise<void>;
    /**
     * Converts data into a json like string
     * @param data Data to convert to JSON
     * @returns JSON data
     */
    toJSON(data: unknown): string;
    /**
     * Client headers
     * @returns AxiosRequestHeaders
     */
    get headers(): AxiosRequestHeaders;
    /**
     * Updates client headers
     */
    set headers(headers: AxiosRequestHeaders);
}
export default Util;
//# sourceMappingURL=Util.d.ts.map